[![Build Status](https://app.travis-ci.com/GrupEstructuraElectronicaSimetria/cosymlib.svg?branch=master)](https://app.travis-ci.com/github/GrupEstructuraElectronicaSimetria/cosymlib)
[![Coverage Status](https://coveralls.io/repos/github/GrupEstructuraElectronicaSimetria/cosymlib/badge.svg?branch=master)](https://coveralls.io/github/GrupEstructuraElectronicaSimetria/cosymlib?branch=master)
[![PyPI version](https://badge.fury.io/py/cosymlib.svg)](https://badge.fury.io/py/symeess)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4925766.svg)](https://doi.org/10.5281/zenodo.4925766)
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/GrupEstructuraElectronicaSimetria/cosymlib/)

CoSymLib
========
Python library for continuous shape and symmetry measures

Main features
-------------
- Continuous Shape and Symmetry measures of molecular geometries
- Continuous Symmetry measures of electronic structure of molecules
- Support for XYZ, coor & fchk file types


Installation instructions
-------------------------
1. Requirements
    - Python 2.7/3.4 or higher
    - Matplotlib
    - Numpy
    - PyYaml
    - Symgroupy
    - Wfnsympy
    - Huckelpy
    - Blas & Lapack libraries
    - Fortran compiler

2. Download the source code and place it in the installation
directory

3. Run setup.py script to install
python setup.py install --user

4. Use the provided script cosym inside scripts folder to run
this software

Contact info
------------
Abel Carreras  
abelcarreras83@gmail.com  
Donostia International Physics Center (DIPC)

Pere Alemany  
p.alemany@ub.edu  
Electronic Structure & Symmetry group  
Department of Materials Science and Physical Chemistry  
Institut de Química Teòrica i Computacional (IQTC-UB)  
University of Barcelona
